@@ -33,8 +33,8 @@ from yapf.yapflib import split_penalty
 from yapf.yapflib import style
 from yapf.yapflib import unwrapped_line
 
-_COMPOUND_STMTS = frozenset({'for', 'while', 'if', 'elif', 'with', 'except',
-                             'def', 'class'})
+_COMPOUND_STMTS = frozenset(
+    {'for', 'while', 'if', 'elif', 'with', 'except', 'def', 'class'})
 
 
 class FormatDecisionState(object):
@@ -125,6 +125,9 @@ class FormatDecisionState(object):
     current = self.next_token
     previous = current.previous_token
 
+    if current.is_pseudo_paren:
+      return False
+
     if current.must_break_before:
       return True
 
@@ -161,6 +164,13 @@ class FormatDecisionState(object):
     if (format_token.Subtype.DICTIONARY_KEY in current.subtypes and
         not current.is_comment):
       # Place each dictionary entry on its own line.
+      if previous.value == '{' and previous.previous_token:
+        opening = _GetOpeningBracket(previous.previous_token)
+        if (opening and opening.value == '(' and opening.previous_token and
+            opening.previous_token.is_name):
+          # This is a dictionary that's an argument to a function.
+          if self._FitsOnLine(previous, previous.matching_bracket):
+            return False
       return True
 
     # TODO(morbo): This should be controlled with a knob.
@@ -209,13 +219,34 @@ class FormatDecisionState(object):
         if previous.is_pseudo_paren:
           # Split before the dictionary value if we can't fit the whole
           # dictionary on one line.
-          if not self._AllDictElementsFitOnOneLine(opening):
+          if not self._EachDictEntryFitsOnOneLine(opening):
             return True
 
-    if (previous.value in '{[' and current.lineno != previous.lineno and
+    if (previous.OpensScope() and not current.OpensScope() and
         format_token.Subtype.SUBSCRIPT_BRACKET not in previous.subtypes):
-      # Retain the split after the container opening.
-      return True
+
+      if not current.is_comment:
+        pprevious = previous.previous_token
+        if pprevious and not pprevious.is_keyword and not pprevious.is_name:
+          # We want to split if there's a comment in the container.
+          token = current
+          while token != previous.matching_bracket:
+            if token.is_comment:
+              return True
+            token = token.next_token
+
+      if previous.value == '(':
+        pptoken = previous.previous_token
+        if not pptoken or not pptoken.is_name:
+          # Split after the opening of a tuple if it doesn't fit on the current
+          # line and it's not a function call.
+          if self._FitsOnLine(previous, previous.matching_bracket):
+            return False
+      else:
+        # Split after the opening of a container if it doesn't fit on the
+        # current line or if it has a comment.
+        if not self._FitsOnLine(previous, previous.matching_bracket):
+          return True
 
     if previous.value == '{':
       closing = previous.matching_bracket
@@ -269,26 +300,26 @@ class FormatDecisionState(object):
       # original comments were on a separate line.
       return True
 
-    opening = _GetOpeningBracket(current)
-    if (opening and opening.value == '(' and current.is_name and
-        previous.value == ','):
+    if current.is_name and previous.value == ',':
       # If we have a function call within an argument list and it won't fit on
       # the remaining line, but it will fit on a line by itself, then go ahead
       # and split before the call.
-      total_len = 0
-      ntoken = current
-      while ntoken:
-        if ntoken.value == '(':
-          total_len = (
-              ntoken.matching_bracket.total_length - current.total_length)
-          break
-        ntoken = ntoken.next_token
+      opening = _GetOpeningBracket(current)
+      if (opening and opening.value == '(' and opening.previous_token and
+          opening.previous_token.is_name):
+        is_func_call = False
+        token = current
+        while token:
+          if token.value == '(':
+            is_func_call = True
+            break
+          if not token.is_name and token.value != '.':
+            break
+          token = token.next_token
 
-      if ntoken:
-        indent_amt = self.stack[-1].indent * style.Get('INDENT_WIDTH')
-        if (total_len + indent_amt < self.column_limit and
-            total_len + self.column >= self.column_limit):
-          return True
+        if is_func_call:
+          if not self._FitsOnLine(current, opening.matching_bracket):
+            return True
 
     return False
 
@@ -497,22 +528,28 @@ class FormatDecisionState(object):
 
   def _FitsOnLine(self, start, end):
     """Determines if line between start and end can fit on the current line."""
-    length = end.total_length - start.total_length
+    length = end.total_length - start.total_length + len(start.value)
     return length + self.column < self.column_limit
 
-  def _AllDictElementsFitOnOneLine(self, opening):
+  def _EachDictEntryFitsOnOneLine(self, opening):
+    """Determine if each dict elems can fit on one line."""
     closing = opening.matching_bracket
-    current, previous = opening.next_token, opening
-    start = None
+    entry_start = opening.next_token
+    current = opening.next_token.next_token
     while current and current != closing:
       if format_token.Subtype.DICTIONARY_KEY in current.subtypes:
-        if start and not self._FitsOnLine(start, current.previous_token):
+        length = current.previous_token.total_length - entry_start.total_length
+        length += len(entry_start.value)
+        if length + self.stack[-2].indent >= self.column_limit:
           return False
-        start = current
+        entry_start = current
       if current.OpensScope():
         current = current.matching_bracket
-      current = current.next_token
-    return start and self._FitsOnLine(start, current.previous_token)
+      else:
+        current = current.next_token
+    length = current.total_length - entry_start.total_length
+    length += len(entry_start.value)
+    return length + self.stack[-2].indent + 2 < self.column_limit
 
 
 def _IsFunctionCallWithArguments(token):
@@ -547,18 +584,6 @@ def _GetOpeningBracket(current):
     current = current.previous_token
   return None
 
-  previous = current
-  if previous and previous.matching_bracket and not previous.is_pseudo_paren:
-    return previous.matching_bracket
-  previous = previous.previous_token
-  while previous and not previous.matching_bracket:
-    previous = previous.previous_token
-    if not previous:
-      break
-    if previous.ClosesScope():
-      previous = previous.matching_bracket.previous_token
-  return previous
-
 
 def _LastTokenInLine(current):
   while not current.is_comment and current.next_token:
@@ -616,3 +641,13 @@ class _ParenState(object):
   def __repr__(self):
     return '[indent::%d, last_space::%d, closing_scope_indent::%d]' % (
         self.indent, self.last_space, self.closing_scope_indent)
+
+  def __eq__(self, other):
+    return hash(self) == hash(other)
+
+  def __ne__(self, other):
+    return not self == other
+
+  def __hash__(self, *args, **kwargs):
+    return hash((self.indent, self.last_space, self.closing_scope_indent,
+                 self.split_before_closing_bracket, self.num_line_splits))
