@@ -41,16 +41,17 @@ class Subtype(object):
   SUBSCRIPT_COLON = 3
   SUBSCRIPT_BRACKET = 4
   DEFAULT_OR_NAMED_ASSIGN = 5
-  VARARGS_STAR = 6
-  KWARGS_STAR_STAR = 7
-  ASSIGN_OPERATOR = 8
-  DICTIONARY_KEY = 9
-  DICTIONARY_VALUE = 10
-  DICT_SET_GENERATOR = 11
-  COMP_FOR = 12
-  COMP_IF = 13
-  DEFAULT_OR_NAMED_ASSIGN_ARG_LIST = 14
-  FUNC_DEF = 15
+  DEFAULT_OR_NAMED_ASSIGN_ARG_LIST = 6
+  VARARGS_LIST = 7
+  VARARGS_STAR = 8
+  KWARGS_STAR_STAR = 9
+  ASSIGN_OPERATOR = 10
+  DICTIONARY_KEY = 11
+  DICTIONARY_VALUE = 12
+  DICT_SET_GENERATOR = 13
+  COMP_FOR = 14
+  COMP_IF = 15
+  FUNC_DEF = 16
 
 
 class FormatToken(object):
@@ -102,6 +103,11 @@ class FormatToken(object):
     else:
       self.spaces_required_before = 0
 
+    if self.is_continuation:
+      self.value = self.node.value.rstrip()
+    else:
+      self.value = self.node.value
+
   def AddWhitespacePrefix(self, newlines_before, spaces=0, indent_level=0):
     """Register a token's whitespace prefix.
 
@@ -120,6 +126,9 @@ class FormatToken(object):
       comment_lines = [s.lstrip() for s in self.value.splitlines()]
       self.node.value = ('\n' + indent_before).join(comment_lines)
 
+      # Update our own value since we are changing node value
+      self.value = self.node.value
+
     if not self.whitespace_prefix:
       self.whitespace_prefix = (
           '\n' * (self.newlines or newlines_before) + indent_before)
@@ -174,12 +183,6 @@ class FormatToken(object):
     msg += ', pseudo)' if self.is_pseudo_paren else ')'
     return msg
 
-  @property
-  def value(self):
-    if self.is_continuation:
-      return self.node.value.rstrip()
-    return self.node.value
-
   @property
   @py3compat.lru_cache()
   def node_split_penalty(self):
