@@ -195,6 +195,7 @@ class BasicBlankLineCalculatorTest(BlankLineCalculatorTest):
         def foo():
           pass
 
+
         # multiline before a
         # class definition
 
@@ -244,7 +245,7 @@ class BasicBlankLineCalculatorTest(BlankLineCalculatorTest):
     uwlines = _ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
-  def testComemntsBeforeDecorator(self):
+  def testCommentsBeforeDecorator(self):
     code = textwrap.dedent("""\
         # The @foo operator adds bork to a().
         @foo()
@@ -265,6 +266,23 @@ class BasicBlankLineCalculatorTest(BlankLineCalculatorTest):
     uwlines = _ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
+  def testCommentsAfterDecorator(self):
+    code = textwrap.dedent("""\
+        class _():
+
+          def _():
+            pass
+
+          @pytest.mark.xfail(reason="#709 and #710")
+          # also
+          #@pytest.mark.xfail(setuptools.tests.is_ascii,
+          #    reason="https://github.com/pypa/setuptools/issues/706")
+          def test_unicode_filename_in_sdist(self, sdist_unicode, tmpdir, monkeypatch):
+            pass
+        """)
+    uwlines = _ParseAndUnwrap(code)
+    self.assertCodeEqual(code, reformatter.Reformat(uwlines))
+
   def testInnerClasses(self):
     unformatted_code = textwrap.dedent("""\
       class DeployAPIClient(object):
